package cours{


	import flash.geom.Rectangle;
	import starling.text.TextField;
	import starling.text.BitmapFont;
	import starling.display.Image;
	
	import com.demonsters.debugger.MonsterDebugger;
	
	import flash.display.Bitmap;

	import starling.display.Button;
	import starling.display.Sprite;
	import starling.events.Event;
	import starling.textures.Texture;

	public class GameMenu extends Sprite
	{
		[Embed(source = "../bin/fonts/scriptina_0.png")]
		private static const BitmapChars : Class;
		
		[Embed(source="../bin/fonts/scriptina.fnt", mimeType="application/octet-stream")]
		private static const ScriptinaXML : Class;
		
		private static const FONT_NAME:String = "Brush Script Std"; 
		
		// état normal du bouton
		[Embed(source = "../bin/assets/button.png")]
		private static const ButtonTextureUp : Class;
		
		// état cliqué du bouton
		[Embed(source = "../bin/assets/button_down.png")]
		private static const ButtonTextureDown : Class;
		
		// éléments du menu
		private var sPartMenu : Vector.<String> = Vector.<String>(["Jouer", "Options", "Règles", "Se connecter"]);
		
		// le fond de notre "jeu"
		[Embed(source = "../bin/assets/background.jpg")] 
		private static const BackgroundImage:Class; 
		 
		private var oBackgroundContainer:Sprite; // le sprite container du fond
		
		// défilement du fond avec 2 images à la suite 
		private var oBackground1:Image; 
		private var oBackground2:Image; 

		public function GameMenu()
		{
			// attend la fin de l'initialisation de la scène
			addEventListener(Event.ADDED_TO_STAGE, onAdded);
		}

		private function onAdded(e : Event) : void
		{
			// création d'un bitmap (fichier spritesheet)
			var bitmap:Bitmap = new BitmapChars(); 
			 
			// création d'une texture à partir du bitmap
			var oTextureFont:Texture = Texture.fromBitmap(bitmap); 
			 
			// création du fichier xml contenant les coordonnées de chaque caractère
			var xmlFont:XML = XML(new ScriptinaXML()); 
			 
			// enregistre la police pour la rendre accessible à l'objet TextField
			TextField.registerBitmapFont(new BitmapFont(oTextureFont, xmlFont)); 

			// création des objets bitmap à partir des images des boutons
			var buttonSkinUp : Bitmap = new ButtonTextureUp();
			var buttonSkinDown : Bitmap = new ButtonTextureDown();

			// création de nos textures pour notre bouton
			var oTextureBtnUp : Texture = Texture.fromBitmap(buttonSkinUp);
			var oTextureBtnDown : Texture = Texture.fromBitmap(buttonSkinDown);

			// création d'un objet bitmap pour le fond 
			var background:Bitmap = new BackgroundImage(); 
			 
			// création de la texture pour le fond 
			var oTextureBtmUpBackground:Texture = Texture.fromBitmap(background); 
			 
			// le sprite container des images de fond 
			oBackgroundContainer = new Sprite(); 
			 
			// création des 2 images pour le défilement 
			oBackground1 = new Image(oTextureBtmUpBackground); 
			oBackground2 = new Image(oTextureBtmUpBackground); 
			 
			// position
			oBackground2.x = oBackground1.width; 
			 
			// ajout sur la scène
			oBackgroundContainer.addChild(oBackground1); 
			oBackgroundContainer.addChild(oBackground2); 
			 
			// affiche le fond container et les images de fond
			addChild(oBackgroundContainer); 
			
			// création d'un sprite container pour le menu
			var menuContainer : Sprite = new Sprite();

			var numPartMenu : uint = sPartMenu.length;
			
			var oButtonMenu : Button;
			for (var i : uint = 0; i < numPartMenu; i++)
			{
				// création d'un bouton du menu en utilisant les textures et le texte
				oButtonMenu = new Button(oTextureBtnUp, sPartMenu[i], oTextureBtnDown);
				
				oButtonMenu.fontName = FONT_NAME;// attribution de la police embarquées
				oButtonMenu.fontColor = 0x006f77;// couleur du texte
				
				// taille de la police au format de l'image png, sans redimensionnement
				oButtonMenu.fontSize = BitmapFont.NATIVE_SIZE;		
				
				// positionne le texte 
				//oButtonMenu.textBounds = new Rectangle(10, 20, 160, 30); 

				oButtonMenu.scaleWhenDown = 0.9;// effect lorsque le bouton est cliqué

				oButtonMenu.y = oButtonMenu.height * i + i*5;// position

				// ajout du bouton dans le container sprite
				menuContainer.addChild(oButtonMenu);
			}

			// écoute l'évènement Event.TRIGGERED, lorsqu'un bouton est cliqué 
			menuContainer.addEventListener(Event.TRIGGERED, onButtonTriggered); 
			
			// écoute sur chaque image 
			stage.addEventListener(Event.ENTER_FRAME, onEnterFrame); 
			
			// centre le menu sur la scène
			menuContainer.x = stage.stageWidth - menuContainer.width >> 1;
			menuContainer.y = stage.stageHeight - menuContainer.height >> 1;

			// affiche le menu
			addChild(menuContainer);
		}
		
		
		/**
		 * Click de l'utilisateur sur le menu.
		 * 
		 */
		private function onButtonTriggered(e:Event) : void
		{
			MonsterDebugger.trace(this, "onButtonTriggered un Button Click !");
			MonsterDebugger.trace(this, Button(e.target).text);
		}
		
		
		/**
		 * Appel à chaque image par secondes.
		 * 
		 */
		private function onEnterFrame(e:Event) : void
		{
			// scroll de l'image de fond
			oBackgroundContainer.x -= 10; 
			
			// reset 
			if ( oBackgroundContainer.x <= -oBackground1.width ) 
			  oBackgroundContainer.x = 0; 
		}
	}
}